contexttools.DynamicMark
========================

.. inheritance-diagram:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark
   :private-bases:

.. autoclass:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.effective_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.format

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.target_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.dynamic_name

Methods
-------

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.attach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.detach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__call__

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__eq__

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__str__

   .. note:: Inherited from `__builtin__.object`
